@@ -9,8 +9,16 @@ def map_exceptions(map: Dict[Type[Exception], Type[Exception]]) -> Iterator[None
     except Exception as exc:  # noqa: PIE786
         for from_exc, to_exc in map.items():
             if isinstance(exc, from_exc):
-                raise to_exc(exc) from None
-        raise
+                raise to_exc(exc)
+        raise  # pragma: nocover
+
+
+class ConnectionNotAvailable(Exception):
+    pass
+
+
+class ProxyError(Exception):
+    pass
 
 
 class UnsupportedProtocol(Exception):
@@ -29,10 +37,6 @@ class LocalProtocolError(ProtocolError):
     pass
 
 
-class ProxyError(Exception):
-    pass
-
-
 # Timeout errors
 
 
@@ -73,7 +77,3 @@ class ReadError(NetworkError):
 
 class WriteError(NetworkError):
     pass
-
-
-class CloseError(NetworkError):
-    pass
